#include <asm/z80/features.h>
#include <stdlib.h>
#include <stdio.h>
#include <float.h>
#include <math.h>
#include <malloc.h>
#include <string.h>
#include "main.h"

// Segment Codes der 7-Segmentanzeige, invertiert, 0 - F
const char digits[16]= {0xc0,0xf5,0xa8,0xb0,0x95,0x92,0x82,0xf4,0x80,0x90,0x84,0x83,0xab,0xa1,0x8a,0x8e};


// Einbindung von Modulen. Variablen etc mssen alle vorher definiert werden
#include "driver.c"
#include "interrupts.c"


/////////////////////////////////////////////////////////
/*
	Initialisierung der gesamten Hardware auf den gewnschten
	Betriebsmodus
*/
/////////////////////////////////////////////////////////

void InitHardware()
{
	// 8255: Mode 0: Port A,B,C Output
	PIO8255_CNTRL  = 0x80; 		//Mode 0: Port A,B,C Output
	PIO8255_PORT_A = 0xff;
	PIO8255_PORT_B = 0;
	PIO8255_PORT_C = 0;

	// 7-Segment ....
	SEG7 = 0xff;

	// STI konfigurieren fr Uart Ausgabe
	STI_UCR   = 0x88;			// = 10001000  UART Control Register 8N1, DIV16
	STI_RSR   = 0x01;			// RX Status - Enable RX
	STI_TSR   = 0x05;			// TX Status - TX High, TX enabled
	// Timer D...
	STI_PVR   = STI_TDDR;		// Zeiger PVR auf Timer D Data
	STI_IDR   = 0x03;			// Timer D Zeitkonstante
	STI_PVR   = STI_TCDCR;		// Zeiger auf Timer C,D Control Register
	STI_IDR   = 0x89;			// Timer D DIV 4, C = Stop
	// GPIO.....
	STI_PVR   = STI_DDR;		// Zeiger PVR auf indirect 6 (DDR)
	STI_IDR   = 0xff;			// GPIO als Output
	STI_GPIP  = 0x00;			// GPIO auf Null setzen
	// Timer A = endlos Run 
	STI_TADR  = 0xff;			// Reload Wert Timer A
	STI_TABCR = 0x70;			// Timer A DIV 200
	STI_PVR   = STI_IERA;		// Timer A Hardware Interrupt einschalten	
	STI_IDR   = 0x20;
	STI_IMRA  = 0x20;			// Timer A Interrupt unmask
	STI_IPRA  = 0x00;			//Pending Ints lschen
	
	// Zuletzt Interrupt Vektor fr Mode 2 laden
	STI_PVR   = 0x40;			// Basisadresse der Ints fr crt0.s Tabelle setzen

	__asm						// Mode 2 Interrupt auswhlen und Ints einschalten
		 im 2
		 ei
	__endasm ;

}

/////////////////////////////////////////////
// Globale Variablen, die NICHT initialisiert
// werden drfen, da Compiler dies nicht kann

#define RX_BUF_LAST 	39
uint8_t rx_buffer[RX_BUF_LAST+1];	// Buffer fr Zeichenempfang
uint8_t rx_ptr;					// Zeiger auf aktuelles Zeichen

#define TX_BUF_LAST 	39
uint8_t tx_buffer[TX_BUF_LAST+1];	// Sendepuffer
uint8_t tx_ptr;					// Zeiger auf aktuelles Zeichen	
uint8_t rx_flag_full;			// Empfangspuffer voll

// Sammlung von Zeichenketten

char array[]="Hallo Welt! Hier bin ich!";
char nummer[10]={1,2,3,4,5,6,7,8,9};
char abc = 5;

const char* const menu[] = {
  "Z80 System is online!\n",
  "---------------------------------",
  "\n(1)...........Load User Program",
  "\n(2)...........Start User Program",
  "\n(3)...........Clear Memory",
  "\n(4)...........Dump Memory",
  "\n(5)...........Restart System",
  "\n(6)...........Basic Interpreter",
  "\n---",
  "\nYour choice?:"
  
};

int main()
{
	////////////////////////////////////////////////////
	InitHardware();
	SetDigit(abc);
	
	while (1);
	
	return (0);

	
}

// An das Ende des Codes die Interrupt Routinen dran hngen


